OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Download" : "Stáhnout",
    "Copy link" : "Zkopírovat odkaz",
    "Click to copy the link to your clipboard" : "Klikněte pro zkopírování odkazu do vaší schránky",
    "Toggle sharing" : "Přepnout sdílení",
    "Delete" : "Smazat",
    "Rename" : "Přejmenovat",
    "Share with users or groups" : "Sdílet suživateli nebo skupinami",
    "can edit" : "může upravovat",
    "Close" : "Zavřít",
    "Enabled" : "Zapnuto",
    "Disabled" : "Vypnuto",
    "Copied!" : "Zkopírováno!",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Pro zkopírování stiskněte ⌘-C.",
    "Press Ctrl-C to copy." : "Pro zkopírování stiskněte Ctrl-C.",
    "Address book name" : "Název adresáře kontaktů",
    "Only these special characters are allowed: -_.!?#|()" : "Jsou povoleny pouze tyto speciální znaky:  -_.!?#|()",
    "Address book could not be created." : "Adresář se nepodařilo vytvořit.",
    "Upload new image" : "Nahrát nový obrázek",
    "The selected image is too big (max 1MB)" : "Zvolený obrázek je příliš velký (max 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Tento kontakt je poškozen a byl obnoven. Prosím zkontrolujete data a proveďte uložení aby byly změny trvalé.",
    "No contacts in here" : "Nejsou zde žádné kontakty",
    "Name" : "Název",
    "Organization" : "Organizace",
    "Title" : "Název",
    "Add field …" : "Přidat pole...",
    "Save changes" : "Uložit změny",
    "Address book" : "Adresář",
    "Loading contacts …" : "Načítání kontaktů…",
    "Import into" : "Importovat do",
    "Importing..." : "Importování…",
    "Select your addressbook" : "Vyberte adresář",
    "No search result for {query}" : "Žádný nález pro {query}",
    "All contacts" : "Všechny kontakty",
    "Post office box" : "Poštovní schránka",
    "Postal code" : "Směrovací číslo",
    "City" : "Město",
    "State or province" : "Stát nebo provincie",
    "Country" : "Země",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "Last name" : "Příjmení",
    "First name" : "Jméno",
    "Additional names" : "Další jména",
    "Prefix" : "Předpona",
    "Suffix" : "Přípona",
    "Importing into" : "Importování do",
    "New contact" : "Nový kontakt",
    "Not grouped" : "Neseskupené",
    "Sort by" : "Seřadit podle",
    "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
    "Contact not found." : "Kontakt nenalezen",
    "You don't have permission to write to this addressbook." : "Nemáte oprávnění k zápisu do tohoto adresáře.",
    "Contact could not be created." : "Kontakt se nepodařilo vytvořit.",
    "No contacts in file. Only vCard files are allowed." : "Žádné kontakty v souboru. Pouze soubory vCard jsou povoleny.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Jsou podporovány pouze vCard verze 4.0 (RFC6350) nebo verze 3.0 (RFC2426).",
    "Contact could not be moved." : "Kontakt nemohl být přesunut.",
    "Contact could not be saved." : "Kontakt nemohl být uložen.",
    "Waiting for the server to be ready…" : "Čekání na odpověď serveru...",
    "Importing…" : "Importování...",
    "Display name" : "Zobrazované jméno",
    "Nickname" : "Přezdívka",
    "Detailed name" : "Jméno podrobně",
    "Notes" : "Poznámky",
    "Website" : "Stránka",
    "Federated Cloud ID" : "Sdružené cloud ID",
    "Home" : "Domů",
    "Work" : "Práce",
    "Other" : "Jiný",
    "Groups" : "Skupiny",
    "Birthday" : "Narozeniny",
    "Anniversary" : "Výročí",
    "Date of death" : "Datum úmrtí",
    "Email" : "E-mail",
    "Instant messaging" : "Komunikátor",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Pracovní mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax domů",
    "Fax work" : "Fax do práce",
    "Pager" : "Pager",
    "Voice" : "Hlas",
    "Car" : "Auto",
    "Work pager" : "Pracovní pager",
    "Social network" : "Sociální síť",
    "Relationship" : "Vztah",
    "Spouse" : "Manželka",
    "Child" : "Dítě",
    "Mother" : "Matka",
    "Father" : "Otec",
    "Parent" : "Rodič",
    "Brother" : "Bratr",
    "Sister" : "Sestra",
    "Relative" : "Příbuzný",
    "Friend" : "Přítel",
    "Colleague" : "Kolega",
    "Manager" : "Nadřízený",
    "Assistant" : "Asistent",
    "Related" : "Související",
    "Contact" : "Kontakt",
    "Emergency" : "Nouze",
    "Co-worker" : "Spolupracovník",
    "Gender" : "Pohlaví",
    "Female" : "Žena",
    "Male" : "Muž",
    "Details" : "Detaily",
    "Settings" : "Nastavení"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
